/*
 * Copyright (c) 2013-2019, The University of Oxford
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of the University of Oxford nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef OSKAR_TELESCOPE_H_
#define OSKAR_TELESCOPE_H_

/**
 * @file oskar_telescope.h
 */

/* Public interface. */

#ifdef __cplusplus
extern "C" {
#endif

struct oskar_Telescope;
#ifndef OSKAR_TELESCOPE_TYPEDEF_
#define OSKAR_TELESCOPE_TYPEDEF_
typedef struct oskar_Telescope oskar_Telescope;
#endif /* OSKAR_TELESCOPE_TYPEDEF_ */

enum OSKAR_POL_MODE_TYPE
{
    OSKAR_POL_MODE_FULL,
    OSKAR_POL_MODE_SCALAR
};

#ifdef __cplusplus
}
#endif

#include <telescope/station/oskar_station.h>
#include <telescope/oskar_telescope_accessors.h>
#include <telescope/oskar_telescope_analyse.h>
#include <telescope/oskar_telescope_create.h>
#include <telescope/oskar_telescope_create_copy.h>
#include <telescope/oskar_telescope_duplicate_first_station.h>
#include <telescope/oskar_telescope_free.h>
#include <telescope/oskar_telescope_load.h>
#include <telescope/oskar_telescope_load_pointing_file.h>
#include <telescope/oskar_telescope_load_position.h>
#include <telescope/oskar_telescope_load_station_coords_ecef.h>
#include <telescope/oskar_telescope_load_station_coords_enu.h>
#include <telescope/oskar_telescope_load_station_coords_wgs84.h>
#include <telescope/oskar_telescope_log_summary.h>
#include <telescope/oskar_telescope_override_element_cable_length_errors.h>
#include <telescope/oskar_telescope_override_element_gains.h>
#include <telescope/oskar_telescope_override_element_phases.h>
#include <telescope/oskar_telescope_resize.h>
#include <telescope/oskar_telescope_save.h>
#include <telescope/oskar_telescope_save_layout.h>
#include <telescope/oskar_telescope_set_station_coords.h>
#include <telescope/oskar_telescope_set_station_coords_ecef.h>
#include <telescope/oskar_telescope_set_station_coords_enu.h>
#include <telescope/oskar_telescope_set_station_coords_wgs84.h>

#endif /* OSKAR_TELESCOPE_H_ */
